<?php

// config for Tricks/LaravelSitemapForDynamicPages

return [
//    'frontend' => [
//        'baseUrl' => env('SITEMAP_FRONTEND_BASEURL'),
//        'paths' => [
//            News::class => [
//                'de' => '/news-events/',
//                'en' => '/en/news-events/',
//                'jp' => '/jp/news-events/'
//            ],
//            Job::class => [
//                'de' => '/karriere/',
//                'en' => '/en/career/',
//                'jp' => '/jp/career/'
//            ]
//        ]
//    ]
];
