<?php

namespace Tricks\LaravelSitemapForDynamicPages\Commands;

use Illuminate\Console\Command;

class LaravelSitemapForDynamicPagesCommand extends Command
{
    public $signature = 'laravel-sitemap-for-dynamic-pages';

    public $description = 'My command';

    public function handle(): int
    {
        $this->comment('All done');

        return self::SUCCESS;
    }
}
