<?php

namespace Tricks\LaravelSitemapForDynamicPages\Facades;

use Illuminate\Support\Facades\Facade;

/**
 * @see \Tricks\LaravelSitemapForDynamicPages\LaravelSitemapForDynamicPages
 */
class LaravelSitemapForDynamicPages extends Facade
{
    protected static function getFacadeAccessor()
    {
        return \Tricks\LaravelSitemapForDynamicPages\LaravelSitemapForDynamicPages::class;
    }
}
